==> trains_agent-0.12.0rc4-py3-none-any.whl: trains_agent/helper/check_update.py <==
import os
from time import sleep

import requests
import json
from threading import Thread
from semantic_version import Version
from ..version import __version__

__check_update_thread = None


def start_check_update_daemon():
    global __check_update_thread
    if __check_update_thread:
        return
    __check_update_thread = Thread(target=_check_update_daemon)
    __check_update_thread.daemon = True
    __check_update_thread.start()


def _check_new_version_available():
    cur_version = __version__
    update_server_releases = requests.get('https://updates.trainsai.io/updates',
                                          data=json.dumps({"versions": {"trains-agent": str(cur_version)}}),
                                          timeout=3.0)
    if update_server_releases.ok:
        update_server_releases = update_server_releases.json()
    else:
        return None
    trains_answer = update_server_releases.get("trains-agent", {})
    latest_version = trains_answer.get("version")
    cur_version = Version(cur_version)
    latest_version = Version(latest_version)
    if cur_version >= latest_version:
        return None
    patch_upgrade = latest_version.major == cur_version.major and latest_version.minor == cur_version.minor
    return str(latest_version), patch_upgrade, trains_answer.get("description").split("\r\n")


def _check_update_daemon():
    counter = 0
    while True:
        # noinspection PyBroadException
        try:
            latest_version = _check_new_version_available()
            # only print when we begin
            if latest_version:
                if latest_version[1]:
                    sep = os.linesep
                    print('TRAINS-AGENT new package available: UPGRADE to v{} is recommended!\nRelease Notes:\n{}'.format(
                        latest_version[0], sep.join(latest_version[2])))
                else:
                    print('TRAINS-SERVER new version available: upgrade to v{} is recommended!'.format(
                        latest_version[0]))
        except Exception:
            pass
        # sleep until the next day
        sleep(60 * 60 * 24)
        counter += 1

==> trains_agent-0.13.2rc2-py3-none-any.whl: trains_agent/helper/check_update.py <==
import os
from time import sleep

import requests
import json
from threading import Thread
from packaging import version as packaging_version
from ..version import __version__

__check_update_thread = None


def start_check_update_daemon():
    global __check_update_thread
    if __check_update_thread:
        return
    __check_update_thread = Thread(target=_check_update_daemon)
    __check_update_thread.daemon = True
    __check_update_thread.start()


def _check_new_version_available():
    cur_version = __version__
    update_server_releases = requests.get('https://updates.trains.allegro.ai/updates',
                                          data=json.dumps({"versions": {"trains-agent": str(cur_version)}}),
                                          timeout=3.0)
    if update_server_releases.ok:
        update_server_releases = update_server_releases.json()
    else:
        return None
    trains_answer = update_server_releases.get("trains-agent", {})
    latest_version = trains_answer.get("version")
    cur_version = packaging_version.parse(cur_version)
    latest_version = packaging_version.parse(latest_version or '')
    if cur_version >= latest_version:
        return None
    patch_upgrade = latest_version.major == cur_version.major and latest_version.minor == cur_version.minor
    return str(latest_version), patch_upgrade, trains_answer.get("description").split("\r\n")


def _check_update_daemon():
    counter = 0
    while True:
        # noinspection PyBroadException
        try:
            latest_version = _check_new_version_available()
            # only print when we begin
            if latest_version:
                if latest_version[1]:
                    sep = os.linesep
                    print('TRAINS-AGENT new package available: UPGRADE to v{} is recommended!\nRelease Notes:\n{}'.format(
                        latest_version[0], sep.join(latest_version[2])))
                else:
                    print('TRAINS-SERVER new version available: upgrade to v{} is recommended!'.format(
                        latest_version[0]))
        except Exception:
            pass
        # sleep until the next day
        sleep(60 * 60 * 24)
        counter += 1
